Struct ItemFlag

pub struct ItemFlag { /* private fields */ }
Available on crate feature tbc only.
Auto generated from the original wowm in file wow_message_parser/wowm/world/queries/smsg_item_query_single_response.wowm:612:

flag ItemFlag : u32 {
    NO_PICKUP = 0x00000001;
    CONJURED = 0x00000002;
    LOOTABLE = 0x00000004;
    DEPRECATED = 0x00000010;
    INDESTRUCTIBLE = 0x00000020;
    PLAYER_CAST = 0x00000040;
    NO_EQUIP_COOLDOWN = 0x00000080;
    INT_BONUS_INSTEAD = 0x00000100;
    WRAPPER = 0x00000200;
    IGNORE_BAG_SPACE = 0x00000400;
    PARTY_LOOT = 0x00000800;
    CHARTER = 0x00002000;
    LETTER = 0x00004000;
    NO_DISENCHANT = 0x00008000;
    REAL_DURATION = 0x00010000;
    NO_CREATOR = 0x00020000;
    PROSPECTABLE = 0x00040000;
    UNIQUE_EQUIPPED = 0x00080000;
    IGNORE_FOR_AURAS = 0x00100000;
    IGNORE_DEFAULT_ARENA_RESTRICTIONS = 0x00200000;
    NO_DURABILITY_LOSS = 0x00400000;
    SPECIAL_USE = 0x00800000;
}

Implementations

Source

impl ItemFlag

pub const NO_PICKUP: u32 = 1u32

pub const CONJURED: u32 = 2u32

pub const LOOTABLE: u32 = 4u32

pub const DEPRECATED: u32 = 16u32

pub const INDESTRUCTIBLE: u32 = 32u32

pub const PLAYER_CAST: u32 = 64u32

pub const NO_EQUIP_COOLDOWN: u32 = 128u32

pub const INT_BONUS_INSTEAD: u32 = 256u32

pub const WRAPPER: u32 = 512u32

pub const IGNORE_BAG_SPACE: u32 = 1_024u32

pub const PARTY_LOOT: u32 = 2_048u32

pub const CHARTER: u32 = 8_192u32

pub const LETTER: u32 = 16_384u32

pub const NO_DISENCHANT: u32 = 32_768u32

pub const REAL_DURATION: u32 = 65_536u32

pub const NO_CREATOR: u32 = 131_072u32

pub const PROSPECTABLE: u32 = 262_144u32

pub const UNIQUE_EQUIPPED: u32 = 524_288u32

pub const IGNORE_FOR_AURAS: u32 = 1_048_576u32

pub const IGNORE_DEFAULT_ARENA_RESTRICTIONS: u32 = 2_097_152u32

pub const NO_DURABILITY_LOSS: u32 = 4_194_304u32

pub const SPECIAL_USE: u32 = 8_388_608u32

pub const fn new(inner: u32) -> ItemFlag

pub const fn empty() -> ItemFlag

pub const fn is_empty(&self) -> bool

pub const fn all() -> ItemFlag

pub const fn is_no_pickup(&self) -> bool

pub const fn new_no_pickup() -> ItemFlag

not used

pub fn set_no_pickup(&mut self) -> ItemFlag

pub fn clear_no_pickup(&mut self) -> ItemFlag

pub const fn is_conjured(&self) -> bool

pub const fn new_conjured() -> ItemFlag

items created by spells with SPELL_EFFECT_CREATE_ITEM

pub fn set_conjured(&mut self) -> ItemFlag

pub fn clear_conjured(&mut self) -> ItemFlag

pub const fn is_lootable(&self) -> bool

pub const fn new_lootable() -> ItemFlag

affect only non container items that can be ‘open’ for loot. It or lockid set enable for client show ‘Right click to open’. See also ITEM_DYNFLAG_UNLOCKED

pub fn set_lootable(&mut self) -> ItemFlag

pub fn clear_lootable(&mut self) -> ItemFlag

pub const fn is_deprecated(&self) -> bool

pub const fn new_deprecated() -> ItemFlag

can’t repeat old note: appears red icon (like when item durability==0)

pub fn set_deprecated(&mut self) -> ItemFlag

pub fn clear_deprecated(&mut self) -> ItemFlag

pub const fn is_indestructible(&self) -> bool

pub const fn new_indestructible() -> ItemFlag

used for totem. Item can not be destroyed, except by using spell (item can be reagent for spell and then allowed)

pub fn set_indestructible(&mut self) -> ItemFlag

pub fn clear_indestructible(&mut self) -> ItemFlag

pub const fn is_player_cast(&self) -> bool

pub const fn new_player_cast() -> ItemFlag

? old note: usable

pub fn set_player_cast(&mut self) -> ItemFlag

pub fn clear_player_cast(&mut self) -> ItemFlag

pub const fn is_no_equip_cooldown(&self) -> bool

pub const fn new_no_equip_cooldown() -> ItemFlag

items without an equip cooldown (and usually a _USABLE flag)

pub fn set_no_equip_cooldown(&mut self) -> ItemFlag

pub fn clear_no_equip_cooldown(&mut self) -> ItemFlag

pub const fn is_int_bonus_instead(&self) -> bool

pub const fn new_int_bonus_instead() -> ItemFlag

saw this on item 47115, 49295…

pub fn set_int_bonus_instead(&mut self) -> ItemFlag

pub fn clear_int_bonus_instead(&mut self) -> ItemFlag

pub const fn is_wrapper(&self) -> bool

pub const fn new_wrapper() -> ItemFlag

used or not used wrapper

pub fn set_wrapper(&mut self) -> ItemFlag

pub fn clear_wrapper(&mut self) -> ItemFlag

pub const fn is_ignore_bag_space(&self) -> bool

pub const fn new_ignore_bag_space() -> ItemFlag

ignore bag space at new item creation?

pub fn set_ignore_bag_space(&mut self) -> ItemFlag

pub fn clear_ignore_bag_space(&mut self) -> ItemFlag

pub const fn is_party_loot(&self) -> bool

pub const fn new_party_loot() -> ItemFlag

items which can be looted by all party members

pub fn set_party_loot(&mut self) -> ItemFlag

pub fn clear_party_loot(&mut self) -> ItemFlag

pub const fn is_charter(&self) -> bool

pub const fn new_charter() -> ItemFlag

arena/guild charter

pub fn set_charter(&mut self) -> ItemFlag

pub fn clear_charter(&mut self) -> ItemFlag

pub const fn is_letter(&self) -> bool

pub const fn new_letter() -> ItemFlag

readable letter items

pub fn set_letter(&mut self) -> ItemFlag

pub fn clear_letter(&mut self) -> ItemFlag

pub const fn is_no_disenchant(&self) -> bool

pub const fn new_no_disenchant() -> ItemFlag

pub fn set_no_disenchant(&mut self) -> ItemFlag

pub fn clear_no_disenchant(&mut self) -> ItemFlag

pub const fn is_real_duration(&self) -> bool

pub const fn new_real_duration() -> ItemFlag

pub fn set_real_duration(&mut self) -> ItemFlag

pub fn clear_real_duration(&mut self) -> ItemFlag

pub const fn is_no_creator(&self) -> bool

pub const fn new_no_creator() -> ItemFlag

pub fn set_no_creator(&mut self) -> ItemFlag

pub fn clear_no_creator(&mut self) -> ItemFlag

pub const fn is_prospectable(&self) -> bool

pub const fn new_prospectable() -> ItemFlag

item can have prospecting loot (in fact some items expected have empty loot)

pub fn set_prospectable(&mut self) -> ItemFlag

pub fn clear_prospectable(&mut self) -> ItemFlag

pub const fn is_unique_equipped(&self) -> bool

pub const fn new_unique_equipped() -> ItemFlag

custom server side check, in client added in 2.x

pub fn set_unique_equipped(&mut self) -> ItemFlag

pub fn clear_unique_equipped(&mut self) -> ItemFlag

pub const fn is_ignore_for_auras(&self) -> bool

pub const fn new_ignore_for_auras() -> ItemFlag

pub fn set_ignore_for_auras(&mut self) -> ItemFlag

pub fn clear_ignore_for_auras(&mut self) -> ItemFlag

pub const fn is_ignore_default_arena_restrictions(&self) -> bool

pub const fn new_ignore_default_arena_restrictions() -> ItemFlag

Item can be used during arena match

pub fn set_ignore_default_arena_restrictions(&mut self) -> ItemFlag

pub fn clear_ignore_default_arena_restrictions(&mut self) -> ItemFlag

pub const fn is_no_durability_loss(&self) -> bool

pub const fn new_no_durability_loss() -> ItemFlag

Some Thrown weapons have it (and only Thrown) but not all

pub fn set_no_durability_loss(&mut self) -> ItemFlag

pub fn clear_no_durability_loss(&mut self) -> ItemFlag

pub const fn is_special_use(&self) -> bool

pub const fn new_special_use() -> ItemFlag

pub fn set_special_use(&mut self) -> ItemFlag

pub fn clear_special_use(&mut self) -> ItemFlag

pub const fn as_int(&self) -> u32