Enum PvpRank
Source pub enum PvpRank {
Show 20 variants
NoRank,
Pariah,
Outlaw,
Exiled,
Dishonored,
Rank1,
Rank2,
Rank3,
Rank4,
Rank5,
Rank6,
Rank7,
Rank8,
Rank9,
Rank10,
Rank11,
Rank12,
Rank13,
Rank14,
FactionLeader,
}
Available on crate feature vanilla only.
Auto generated from the original wowm in file wow_message_parser/wowm/world/pvp/pvp_common.wowm:3:
enum PvpRank : u8 {
NO_RANK = 0;
PARIAH = 1;
OUTLAW = 2;
EXILED = 3;
DISHONORED = 4;
RANK1 = 5;
RANK2 = 6;
RANK3 = 7;
RANK4 = 8;
RANK5 = 9;
RANK6 = 10;
RANK7 = 11;
RANK8 = 12;
RANK9 = 13;
RANK10 = 14;
RANK11 = 15;
RANK12 = 16;
RANK13 = 17;
RANK14 = 18;
FACTION_LEADER = 19;
}
Alliance name: Private
Horde name: Scout
Alliance name: Corporal
Horde name: Grunt
Alliance name: Sergeant
Horde name: Sergeant
Alliance name: Master Sergeant
Horde name: Senior Sergeatn
Alliance name: Sergeant Major
Horde name: First Sergeant
Alliance name: Knight
Horde name: Stone Guard
Alliance name: Knight Lieutenant
Horde name: Blood Guard
Alliance name: Knight Captain
Horde name: Legionnare
Alliance name: Kngith Champion
Horde name: Centurion
Alliance name: Liuetenant Commander
Horde name: Champion
Alliance name: Commander
Horde name: Lieutenant General
Alliance name: Marshal
Horde name: General
Alliance name: Field Marshal
Horde name: Warlord
Alliance name: Grand Marshal
Horde name: High Warlord
Available on crate feature tbc only.
Available on crate feature tbc only.
Available on crate feature tbc only.
Performs copy-assignment from
source.
Read more
Formats the value using the given formatter.
Read more
Returns the “default value” for a type.
Read more
Formats the value using the given formatter.
Read more
Compares and returns the maximum of two values.
Read more
Compares and returns the minimum of two values.
Read more
Restrict a value to a certain interval.
Read more
Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more
Tests less than (for
self and
other) and is used by the
< operator.
Read more
Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more
Tests greater than (for
self and
other) and is used by the
>
operator.
Read more
Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
Converts the given value to a
String.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.