pub enum ItemClassAndSubClass {
Show 119 variants
Consumable,
FoodAndDrink,
Potion,
Elixir,
Flask,
Bandage,
ItemEnhancement,
Scroll,
OtherConsumable,
Bag,
SoulBag,
HerbBag,
EnchantingBag,
EngineeringBag,
GemBag,
MiningBag,
LeatherworkingBag,
InscriptionBag,
OneHandedAxe,
TwoHandedAxe,
Bow,
Gun,
OneHandedMace,
TwoHandedMace,
Polearm,
OneHandedSword,
TwoHandedSword,
ObsoleteWeapon,
Staff,
OneHandedExotic,
TwoHandedExotic,
FistWeapon,
MiscellaneousWeapon,
Dagger,
Thrown,
Spear,
Crossbow,
Wand,
FishingPole,
GemRed,
GemBlue,
GemYellow,
GemPurple,
GemGreen,
GemOrange,
GemMeta,
GemSimple,
GemPrismatic,
MiscellaneousArmor,
ClothArmor,
LeatherArmor,
MailArmor,
PlateArmor,
BucklerObsolete,
Shield,
Libram,
Idol,
Totem,
Sigil,
Reagent,
WandObsolete,
BoltObsolete,
Arrow,
Bullet,
ThrownObsolete,
TradeGood,
ElementalTradeGood,
ClothTradeGood,
LeatherTradeGood,
MetalAndStoneTradeGood,
MeatTradeGood,
HerbTradeGood,
EnchantingTradeGood,
JewelcraftingTradeGood,
PartTradeGood,
DeviceTradeGood,
ExplosiveTradeGood,
MaterialTradeGood,
OtherTradeGood,
ArmorEnchantmentTradeGood,
WeaponEnchantmentTradeGood,
GenericObsolete,
Book,
LeatherworkingRecipe,
TailoringRecipe,
EngineeringRecipe,
BlacksmithingRecipe,
CookingRecipe,
AlchemyRecipe,
FirstAidRecipe,
EnchantingRecipe,
FishingRecipe,
JewelcraftingRecipe,
InscriptionRecipe,
MoneyObsolete,
QuiverObsolete,
QuiverObsolete1,
Quiver,
AmmoPouch,
Quest,
Key,
Lockpick,
PermanentObsolete,
MiscellaneousJunk,
MiscellaneousReagent,
MiscellaneousPet,
MiscellaneousHoliday,
MiscellaneousOther,
MiscellaneousMount,
WarriorGlyph,
PaladinGlyph,
HunterGlyph,
RogueGlyph,
PriestGlyph,
DeathKnightGlyph,
ShamanGlyph,
MageGlyph,
WarlockGlyph,
DruidGlyph,
}Available on crate feature
wrath only.Expand description
This is both the class field and the sub class field.
They are combined into one enum because the value of the sub class depends on the value of the class.
The high bits of this are the class field since they are both sent as little endian.
Auto generated from the original wowm in file wow_message_parser/wowm/world/enums/item_class_and_sub_class.wowm:197:
enum ItemClassAndSubClass : u64 {
CONSUMABLE = 0x0000000000000000;
FOOD_AND_DRINK = 0x0000000500000000;
POTION = 0x0000000100000000;
ELIXIR = 0x0000000200000000;
FLASK = 0x0000000300000000;
BANDAGE = 0x0000000700000000;
ITEM_ENHANCEMENT = 0x0000000600000000;
SCROLL = 0x0000000400000000;
OTHER_CONSUMABLE = 0x0000000800000000;
BAG = 0x0000000000000001;
SOUL_BAG = 0x0000000100000001;
HERB_BAG = 0x0000000200000001;
ENCHANTING_BAG = 0x0000000300000001;
ENGINEERING_BAG = 0x0000000400000001;
GEM_BAG = 0x0000000500000001;
MINING_BAG = 0x0000000600000001;
LEATHERWORKING_BAG = 0x0000000700000001;
INSCRIPTION_BAG = 0x0000000800000001;
ONE_HANDED_AXE = 0x0000000000000002;
TWO_HANDED_AXE = 0x0000000100000002;
BOW = 0x0000000200000002;
GUN = 0x0000000300000002;
ONE_HANDED_MACE = 0x0000000400000002;
TWO_HANDED_MACE = 0x0000000500000002;
POLEARM = 0x0000000600000002;
ONE_HANDED_SWORD = 0x0000000700000002;
TWO_HANDED_SWORD = 0x0000000800000002;
OBSOLETE_WEAPON = 0x0000000900000002;
STAFF = 0x0000000a00000002;
ONE_HANDED_EXOTIC = 0x0000000b00000002;
TWO_HANDED_EXOTIC = 0x0000000c00000002;
FIST_WEAPON = 0x0000000d00000002;
MISCELLANEOUS_WEAPON = 0x0000000e00000002;
DAGGER = 0x0000000f00000002;
THROWN = 0x0000001000000002;
SPEAR = 0x0000001100000002;
CROSSBOW = 0x0000001200000002;
WAND = 0x0000001300000002;
FISHING_POLE = 0x0000001400000002;
GEM_RED = 0x0000000000000003;
GEM_BLUE = 0x0000000100000003;
GEM_YELLOW = 0x0000000200000003;
GEM_PURPLE = 0x0000000300000003;
GEM_GREEN = 0x0000000400000003;
GEM_ORANGE = 0x0000000500000003;
GEM_META = 0x0000000600000003;
GEM_SIMPLE = 0x0000000700000003;
GEM_PRISMATIC = 0x0000000800000003;
MISCELLANEOUS_ARMOR = 0x0000000000000004;
CLOTH_ARMOR = 0x0000000100000004;
LEATHER_ARMOR = 0x0000000200000004;
MAIL_ARMOR = 0x0000000300000004;
PLATE_ARMOR = 0x0000000400000004;
BUCKLER_OBSOLETE = 0x0000000500000004;
SHIELD = 0x0000000600000004;
LIBRAM = 0x0000000700000004;
IDOL = 0x0000000800000004;
TOTEM = 0x0000000900000004;
SIGIL = 0x0000000a00000004;
REAGENT = 0x0000000000000005;
WAND_OBSOLETE = 0x0000000000000006;
BOLT_OBSOLETE = 0x0000000100000006;
ARROW = 0x0000000200000006;
BULLET = 0x0000000300000006;
THROWN_OBSOLETE = 0x0000000400000006;
TRADE_GOOD = 0x0000000000000007;
ELEMENTAL_TRADE_GOOD = 0x0000000a00000007;
CLOTH_TRADE_GOOD = 0x0000000500000007;
LEATHER_TRADE_GOOD = 0x0000000600000007;
METAL_AND_STONE_TRADE_GOOD = 0x0000000700000007;
MEAT_TRADE_GOOD = 0x0000000800000007;
HERB_TRADE_GOOD = 0x0000000900000007;
ENCHANTING_TRADE_GOOD = 0x0000000c00000007;
JEWELCRAFTING_TRADE_GOOD = 0x0000000400000007;
PART_TRADE_GOOD = 0x0000000100000007;
DEVICE_TRADE_GOOD = 0x0000000300000007;
EXPLOSIVE_TRADE_GOOD = 0x0000000200000007;
MATERIAL_TRADE_GOOD = 0x0000000d00000007;
OTHER_TRADE_GOOD = 0x0000000b00000007;
ARMOR_ENCHANTMENT_TRADE_GOOD = 0x0000000e00000007;
WEAPON_ENCHANTMENT_TRADE_GOOD = 0x0000000f00000007;
GENERIC_OBSOLETE = 0x0000000000000008;
BOOK = 0x0000000000000009;
LEATHERWORKING_RECIPE = 0x0000000100000009;
TAILORING_RECIPE = 0x0000000200000009;
ENGINEERING_RECIPE = 0x0000000300000009;
BLACKSMITHING_RECIPE = 0x0000000400000009;
COOKING_RECIPE = 0x0000000500000009;
ALCHEMY_RECIPE = 0x0000000600000009;
FIRST_AID_RECIPE = 0x0000000700000009;
ENCHANTING_RECIPE = 0x0000000800000009;
FISHING_RECIPE = 0x0000000900000009;
JEWELCRAFTING_RECIPE = 0x0000000a00000009;
INSCRIPTION_RECIPE = 0x0000000b00000009;
MONEY_OBSOLETE = 0x000000000000000a;
QUIVER_OBSOLETE = 0x000000000000000b;
QUIVER_OBSOLETE1 = 0x000000010000000b;
QUIVER = 0x000000020000000b;
AMMO_POUCH = 0x000000030000000b;
QUEST = 0x000000000000000c;
KEY = 0x000000000000000d;
LOCKPICK = 0x000000010000000d;
PERMANENT_OBSOLETE = 0x000000000000000e;
MISCELLANEOUS_JUNK = 0x000000000000000f;
MISCELLANEOUS_REAGENT = 0x000000010000000f;
MISCELLANEOUS_PET = 0x000000020000000f;
MISCELLANEOUS_HOLIDAY = 0x000000030000000f;
MISCELLANEOUS_OTHER = 0x000000040000000f;
MISCELLANEOUS_MOUNT = 0x000000050000000f;
WARRIOR_GLYPH = 0x0000000100000010;
PALADIN_GLYPH = 0x0000000200000010;
HUNTER_GLYPH = 0x0000000300000010;
ROGUE_GLYPH = 0x0000000400000010;
PRIEST_GLYPH = 0x0000000500000010;
DEATH_KNIGHT_GLYPH = 0x0000000600000010;
SHAMAN_GLYPH = 0x0000000700000010;
MAGE_GLYPH = 0x0000000800000010;
WARLOCK_GLYPH = 0x0000000900000010;
DRUID_GLYPH = 0x0000000b00000010;
}Variants
Consumable
FoodAndDrink
Potion
Elixir
Flask
Bandage
ItemEnhancement
Scroll
OtherConsumable
Bag
SoulBag
HerbBag
EnchantingBag
EngineeringBag
GemBag
MiningBag
LeatherworkingBag
InscriptionBag
OneHandedAxe
TwoHandedAxe
Bow
Gun
OneHandedMace
TwoHandedMace
Polearm
OneHandedSword
TwoHandedSword
ObsoleteWeapon
Staff
OneHandedExotic
TwoHandedExotic
FistWeapon
MiscellaneousWeapon
Dagger
Thrown
Spear
Crossbow
Wand
FishingPole
GemRed
GemBlue
GemYellow
GemPurple
GemGreen
GemOrange
GemMeta
GemSimple
GemPrismatic
MiscellaneousArmor
ClothArmor
LeatherArmor
MailArmor
PlateArmor
BucklerObsolete
Shield
Libram
Idol
Totem
Sigil
Reagent
WandObsolete
BoltObsolete
Arrow
Bullet
ThrownObsolete
TradeGood
ElementalTradeGood
ClothTradeGood
LeatherTradeGood
MetalAndStoneTradeGood
MeatTradeGood
HerbTradeGood
EnchantingTradeGood
JewelcraftingTradeGood
PartTradeGood
DeviceTradeGood
ExplosiveTradeGood
MaterialTradeGood
OtherTradeGood
ArmorEnchantmentTradeGood
WeaponEnchantmentTradeGood
GenericObsolete
Book
LeatherworkingRecipe
TailoringRecipe
EngineeringRecipe
BlacksmithingRecipe
CookingRecipe
AlchemyRecipe
FirstAidRecipe
EnchantingRecipe
FishingRecipe
JewelcraftingRecipe
InscriptionRecipe
MoneyObsolete
QuiverObsolete
QuiverObsolete1
Quiver
AmmoPouch
Quest
Key
Lockpick
PermanentObsolete
MiscellaneousJunk
MiscellaneousReagent
MiscellaneousPet
MiscellaneousHoliday
MiscellaneousOther
MiscellaneousMount
WarriorGlyph
PaladinGlyph
HunterGlyph
RogueGlyph
PriestGlyph
DeathKnightGlyph
ShamanGlyph
MageGlyph
WarlockGlyph
DruidGlyph
Implementations