Enum Language

pub enum Language {
Show 18 variants Universal, Orcish, Darnassian, Taurahe, Dwarvish, Common, Demonic, Titan, Thalassian, Draconic, Kalimag, Gnomish, Troll, Gutterspeak, Draenei, Zombie, GnomishBinary, GoblinBinary,
}
Available on crate feature wrath only.
Auto generated from the original wowm in file wow_message_parser/wowm/world/social/social_common_2_4_3.wowm:359:

enum Language : u8 {
    UNIVERSAL = 0;
    ORCISH = 1;
    DARNASSIAN = 2;
    TAURAHE = 3;
    DWARVISH = 6;
    COMMON = 7;
    DEMONIC = 8;
    TITAN = 9;
    THALASSIAN = 10;
    DRACONIC = 11;
    KALIMAG = 12;
    GNOMISH = 13;
    TROLL = 14;
    GUTTERSPEAK = 33;
    DRAENEI = 35;
    ZOMBIE = 36;
    GNOMISH_BINARY = 37;
    GOBLIN_BINARY = 38;
}

Variants



Universal



Orcish



Darnassian



Taurahe



Dwarvish



Common



Demonic



Titan



Thalassian



Draconic



Kalimag



Gnomish



Troll



Gutterspeak



Draenei



Zombie



GnomishBinary



GoblinBinary

Implementations

Source

impl Language

pub const fn as_int(&self) -> u8

Available on crate feature tbc only.
pub const fn variants() -> [Language; 18]

Available on crate feature tbc only.
pub const fn from_int(value: u8) -> Result<Language, EnumError>

Available on crate feature tbc only.